/*
 * Copyright (C) 2004-2010 Geometer Plus <contact@geometerplus.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef __ENTITYFILESCOLLECTOR_H__
#define __ENTITYFILESCOLLECTOR_H__

#include <map>
#include <vector>
#include <string>

class EntityFilesCollector {

public:
	static EntityFilesCollector &Instance();

	const std::vector<std::string> &externalDTDs(const std::string &format);

private:
	EntityFilesCollector();

private:
	static EntityFilesCollector *ourInstance;
	std::map<std::string,std::vector<std::string> > myCollections;
};

#endif /* __ENTITYFILESCOLLECTOR_H__ */
